@@ -23,13 +23,9 @@ use parent qw(
 
 WWW::YoutubeViewer - A very easy interface to YouTube.
 
-=head1 VERSION
-
-Version 3.2.2
-
 =cut
 
-our $VERSION = '3.2.2';
+our $VERSION = '3.2.5';
 
 =head1 SYNOPSIS
 
@@ -306,54 +302,57 @@ Get and return the content for $url.
 sub lwp_get {
     my ($self, $url, $simple) = @_;
 
+    $url // return;
     $self->{lwp} // $self->set_lwp_useragent();
 
     my %lwp_header = ($simple ? () : $self->_get_lwp_header);
+
+    state $accepted_encodings = do {
+        require HTTP::Message;
+        HTTP::Message::decodable();
+    };
+
+    $lwp_header{'Accept-Encoding'} = $accepted_encodings;
+
     my $response = $self->{lwp}->get($url, %lwp_header);
 
     if ($response->is_success) {
         return $response->decoded_content;
     }
-    else {
-        my $status = $response->status_line;
 
-        if ($status =~ /^401 / and defined($self->get_refresh_token)) {
-            if (defined(my $refresh_token = $self->oauth_refresh_token())) {
-                if (defined $refresh_token->{access_token}) {
+    if ($response->status_line() =~ /^401 / and defined($self->get_refresh_token)) {
+        if (defined(my $refresh_token = $self->oauth_refresh_token())) {
+            if (defined $refresh_token->{access_token}) {
 
-                    $self->set_access_token($refresh_token->{access_token});
+                $self->set_access_token($refresh_token->{access_token});
 
-                    # Don't be tempted to use recursion here, because bad things will happen!
-                    my $new_resp = $self->{lwp}->get($url, $self->_get_lwp_header);
+                # Don't be tempted to use recursion here, because bad things will happen!
+                $response = $self->{lwp}->get($url, $self->_get_lwp_header);
 
-                    if ($new_resp->is_success) {
-                        $self->save_authentication_tokens();
-                        return $new_resp->decoded_content;
-                    }
-                    elsif ($new_resp->status_line() =~ /^401 /) {
-                        $self->set_refresh_token();    # refresh token was invalid
-                        $self->set_access_token();     # access token is also broken
-                        warn "[!] Can't refresh the access token! Logging out...\n";
-                    }
-                    else {
-                        warn '[' . $new_resp->status_line . "] Error occured on URL: $url\n";
-                    }
+                if ($response->is_success) {
+                    $self->save_authentication_tokens();
+                    return $response->decoded_content;
                 }
-                else {
-                    warn "[!] Can't get the access_token! Logging out...\n";
-                    $self->set_refresh_token();
-                    $self->set_access_token();
+                elsif ($response->status_line() =~ /^401 /) {
+                    $self->set_refresh_token();    # refresh token was invalid
+                    $self->set_access_token();     # access token is also broken
+                    warn "[!] Can't refresh the access token! Logging out...\n";
                 }
             }
             else {
-                warn "[!] Invalid refresh_token! Logging out...\n";
+                warn "[!] Can't get the access_token! Logging out...\n";
                 $self->set_refresh_token();
                 $self->set_access_token();
             }
         }
-        warn '[' . $response->status_line . "] Error occured on URL: $url\n";
+        else {
+            warn "[!] Invalid refresh_token! Logging out...\n";
+            $self->set_refresh_token();
+            $self->set_access_token();
+        }
     }
 
+    warn '[' . $response->status_line . "] Error occured on URL: $url\n";
     return;
 }
 
@@ -531,7 +530,7 @@ sub _get_formats_from_ytdl {
       || return;
 
     my $json = $self->proxy_stdout('youtube-dl', '--all-formats', '--dump-single-json',
-                                   quotemeta("http://www.youtube.com/watch?v=" . $videoID));
+                                   quotemeta("https://www.youtube.com/watch?v=" . $videoID));
 
     my @array;
     my $ref = $self->parse_json_string($json) // return;
